@@ -1,4 +1,4 @@
-# Copyrights 2007-2014 by [Mark Overmeer].
+# Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP;
 use vars '$VERSION';
-$VERSION = '3.06';
+$VERSION = '3.07';
 
 
 use Log::Report          'xml-compile-soap';
@@ -421,7 +421,8 @@ sub _receiver(@)
     my $style  = $args{style} || 'document';
     my $kind   = $args{kind}  || 'request-response';
     if($style eq 'rpc')
-    {   my $procedure = $args{procedure} || $args{body}{procedure}
+    {   my $procedure = $args{procedure} || $args{body}{procedure};
+        keys %{$args{body}}==0 || $procedure
             or error __x"receiving operation requires procedure name with RPC";
 
         my $use = $args{use} || $args{body}{use} || 'literal';
