@@ -1,4 +1,4 @@
-# Copyrights 2007-2014 by [Mark Overmeer].
+# Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP11::Operation;
 use vars '$VERSION';
-$VERSION = '3.06';
+$VERSION = '3.07';
 
 use base 'XML::Compile::SOAP::Operation';
 
@@ -84,8 +84,8 @@ sub _msg_parts($$$$$)
         my @parts     = $class->_select_parts($wsdl, $msgname, $body->{parts});
 
         my ($ns, $local) = unpack_type $msgname;
-        my $rpc_ns    = $body->{namespace};
-        $wsdl->addNicePrefix(call => $rpc_ns);
+        my $rpc_ns    = $body->{namespace} // '';
+        $wsdl->addNicePrefix(call => $rpc_ns) if $rpc_ns;
 
         my $procedure
            = $style eq 'rpc' ? pack_type($rpc_ns, $opname)
