@@ -1,4 +1,4 @@
-# Copyrights 2007-2014 by [Mark Overmeer].
+# Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::Transport::SOAPHTTP;
 use vars '$VERSION';
-$VERSION = '3.06';
+$VERSION = '3.07';
 
 use base 'XML::Compile::Transport';
 
@@ -57,12 +57,15 @@ sub userAgent(;$)
 
     $self->{user_agent} ||= $default_ua ||= LWP::UserAgent->new
       ( requests_redirectable => [ qw/GET HEAD POST M-POST/ ]
-      , parse_head => 0
-      , protocols_allowed => [ qw/http https/ ]
+      , protocols_allowed     => [ qw/http https/ ]
+      , parse_head            => 0
       , @_
       );
 }
 
+
+sub defaultUserAgent() { $default_ua }
+
 #-------------------------------------------
 
 
@@ -177,7 +180,6 @@ sub _prepare_call($)
 
         $trace->{http_request}  = $request;
 
-#warn $request->as_string;
         my $response = $ua->request($request)
             or return undef;
 
@@ -214,7 +216,7 @@ sub _prepare_simple_call($)
         lc($ct) ne 'multipart/related'
             or error __x"remote system uses XOP, use XML::Compile::XOP";
  
-        info "received ".$response->status_line;
+        trace "received ".$response->status_line;
 
         $ct =~ m,[/+]xml$,i
             or error __x"answer is not xml but `{type}'", type => $ct;
@@ -305,7 +307,7 @@ sub _prepare_for_no_answer($)
       { my $response = shift;
         my $ct       = $response->content_type || '';
 
-        info "received ".$response->status_line;
+        trace "received ".$response->status_line;
 
         my $content = '';
         if($ct =~ m,[/+]xml$,i)
